==> hs-cpphs-1.11_2.tbz: lib/ghc-7.0.3/cabal/cpphs-1.11/register.sh <==
#!/bin/sh
echo 'name: cpphs
version: 1.11
id: cpphs-1.11-ae0dbfe075a323e48ed157f8dae0f0e2

license: LGPL
copyright: 2004-2010, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@cs.york.ac.uk>
stability:
homepage: http://haskell.org/cpphs/
package-url:
description: Cpphs is a re-implementation of the C pre-processor that is both
             more compatible with Haskell, and itself written in Haskell so
             that it can be distributed with compilers.
             .
             This version of the C pre-processor is pretty-much
             feature-complete and compatible with traditional (K&R)
             pre-processors.  Additional features include: a plain-text mode;
             an option to unlit literate code files; and an option to turn
             off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@cs.york.ac.uk>
exposed: True
exposed-modules: Language.Preprocessor.Cpphs
                 Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
                Text.ParserCombinators.HuttonMeijer
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/cpphs-1.11
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/cpphs-1.11
              /usr/local/lib
hs-libraries: HScpphs-1.11
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-63fd52d9e7e39016c91be0baf3543757
         haskell98-1.1.0.1-b5235617d15eeebf246dacfc99755a36
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/cpphs-1.11/html/cpphs.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/cpphs-1.11/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-cpphs-1.13.2.tbz: lib/ghc-7.0.4/cabal/cpphs-1.13.2/register.sh <==
#!/bin/sh
echo 'name: cpphs
version: 1.13.2
id: cpphs-1.13.2-656009fa063ee4a4a61a25d6e7964558

license: LGPL
copyright: 2004-2011, Malcolm Wallace
maintainer: Malcolm Wallace <Malcolm.Wallace@me.com>
stability:
homepage: http://haskell.org/cpphs/
package-url:
description: Cpphs is a re-implementation of the C pre-processor that is both
             more compatible with Haskell, and itself written in Haskell so
             that it can be distributed with compilers.
             .
             This version of the C pre-processor is pretty-much
             feature-complete and compatible with traditional (K&R)
             pre-processors.  Additional features include: a plain-text mode;
             an option to unlit literate code files; and an option to turn
             off macro-expansion.
category: Development
author: Malcolm Wallace <Malcolm.Wallace@me.com>
exposed: True
exposed-modules: Language.Preprocessor.Cpphs
                 Language.Preprocessor.Unlit
hidden-modules: Language.Preprocessor.Cpphs.CppIfdef
                Language.Preprocessor.Cpphs.HashDefine
                Language.Preprocessor.Cpphs.MacroPass
                Language.Preprocessor.Cpphs.Options
                Language.Preprocessor.Cpphs.Position
                Language.Preprocessor.Cpphs.ReadFirst
                Language.Preprocessor.Cpphs.RunCpphs
                Language.Preprocessor.Cpphs.SymTab
                Language.Preprocessor.Cpphs.Tokenise
                Text.ParserCombinators.HuttonMeijer
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/cpphs-1.13.2
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/cpphs-1.13.2
              /usr/local/lib
hs-libraries: HScpphs-1.13.2
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-c683e1c476645dcbab1b168f8e5a9aeb
         directory-1.1.0.0-689c0feb497f60ef9b6c9a128fc1997e
         old-locale-1.0.0.2-cc522edd16b73a70b897598c5f5d20c7
         old-time-1.0.0.6-64e7d46ef71d3ea7f6d3a651bbb2bcca
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/cpphs-1.13.2/html/cpphs.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/cpphs-1.13.2/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
